@@ -9,16 +9,19 @@ def ret_status(elem):
 	ret = build_ret(elem)
 	ret.update({
 		'color' : elem['status']['color'],
-		'name' : elem['status']['name']
+		'value' : elem['status']['name']
 	})
 	return ret
 
 def ret_date(elem):
-	ret = build_ret(elem)
+	ret = {
+		'properties' : elem,
+		'value_start' : None
+	}
 	if elem['date'] != None:
 		ret.update({
-			'start' : elem['date']['start'],
-			'end' : elem['date']['end']
+			'value_start' : elem['date']['start'],
+			'value_end' : elem['date']['end']
 		})
 	return ret
 
@@ -26,8 +29,7 @@ def ret_formula(elem):
 	ret = build_ret(elem)
 	if elem['formula'] != None:
 		ret.update({
-			'type' : 'number',
-			'number' : elem['formula']['number']
+			'value' : elem['formula']['number']
 		})
 	return ret
 
@@ -35,7 +37,7 @@ def ret_rich_text(elem):
 	ret = build_ret(elem)
 	if elem['rich_text'] != []:
 		ret.update({
-			'rich_text' : elem['rich_text'][0]['plain_text']
+			'value' : elem['rich_text'][0]['plain_text']
 		})
 	return ret
 
@@ -43,14 +45,14 @@ def ret_title(elem):
 	ret = build_ret(elem)
 	if elem['title'] != []:
 		ret.update({
-			'title' : elem['title'][0]['plain_text']
+			'value' : elem['title'][0]['plain_text']
 		})
 	return ret
 
 def ret_number(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'number' : elem['number']
+		'value' : elem['number']
 	})
 	return ret
 
@@ -59,74 +61,72 @@ def ret_select(elem):
 	if elem['select'] != None:
 		ret.update({
 			'color' : elem['select']['color'],
-			'name' : elem['select']['name']
+			'value' : elem['select']['name']
 		})
 	return ret
 
 def ret_multi_select(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'multi_select' : []
+		'value' : []
 	})
 	for select in elem['multi_select']:
 		data = {
 		'color' : select['color'],
 		'name' : select['name']
 		}
-		ret['multi_select'].append(data)
+		ret['value'].append(data)
 	return ret
 
 def ret_checkbox(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'checkbox' : elem['checkbox']
+		'value' : elem['checkbox']
 	})
 	return ret
 
 def ret_people(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'people' : []
+		'value' : []
 	})
 	for people in elem['people']:
-		ret['people'].append(people['name'])
+		ret['value'].append(people['name'])
 	return ret
 
 def ret_url(elem):
 	ret = build_ret(elem)
 	if elem['url'] != None:
 		ret.update({
-			'url' : elem['url']
+			'value' : elem['url']
 		})
 	return ret
 
 def ret_created_time(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'created_time' : elem['created_time']
+		'value_time' : elem['created_time']
 	})
 	return ret
 
 def ret_created_by(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'creator_id' : elem['created_by']['id'],
-		'creator_name' : elem['created_by']['name']
+		'value' : elem['created_by']['name']
 	})
 	return ret
 
 def ret_last_edited_time(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'last_edited_time' : elem['last_edited_time']
+		'value_time' : elem['last_edited_time']
 	})
 	return ret
 
 def ret_last_edited_by(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'editor_id' : elem['last_edited_by']['id'],
-		'editor_name' : elem['last_edited_by']['name']
+		'value_name' : elem['last_edited_by']['name']
 	})
 	return ret
 
@@ -134,7 +134,7 @@ def ret_email(elem):
 	ret = build_ret(elem)
 	if elem['email'] != None:
 		ret.update({
-			'email' : elem['email']
+			'value' : elem['email']
 		})
 	return ret
 
@@ -142,7 +142,7 @@ def ret_phone_number(elem):
 	ret = build_ret(elem)
 	if elem['phone_number'] != None:
 		ret.update({
-			'phone_number' : elem['phone_number']
+			'value' : elem['phone_number']
 		})
 	return ret
 
