@@ -73,10 +73,6 @@ class update_properties:
 	def update_status(self, elem):
 		return elem
 
-	def update_number(self, elem):
-		if elem['update'] == True:
-			elem['properties']['number'] = elem['number']
-		return elem
 
 	def update_select(self, elem):
 		return elem
@@ -108,6 +104,26 @@ class update_properties:
 			elem['properties']['phone_number'] = elem['phone_number']
 		return elem
 
+
+	def update_created_by(self, elem):
+		return None
+
+	def update_last_edited_by(self, elem):
+		return None
+
+	def update_last_edited_time(self, elem):
+		return None
+
+	def update_created_time(self, elem):
+		return None
+
+	def update_number(self, elem):
+		if elem['properties']['number'] != elem['value']:
+			elem['properties']['number'] = elem['number']
+		else:
+			return None
+		return elem
+
 	def update_people(self, elem):
 		if elem['update'] == True:
 			elem['properties']['people'] = []
@@ -117,20 +133,8 @@ class update_properties:
 						elem['properties']['people'].append(user)
 		return elem
 
-	def update_created_by(self, elem):
-		return elem
-
-	def update_last_edited_by(self, elem):
-		return elem
-
-	def update_last_edited_time(self, elem):
-		return(elem)
-
-	def update_created_time(self, elem):
-		return (elem)
-
-	def update_properties(self):
-		ret = {
+	def update_properties(self, elem):
+		function = {
 			"title" : self.update_title,
 			"rich_text" : self.update_rich_text,
 			"date" : self.update_date,
@@ -148,4 +152,5 @@ class update_properties:
 			"created_by": self.update_created_by,
 			"created_time": self.update_created_time
 		}
+		ret = function[elem['type']](elem)
 		return ret
